% Code Main Text and Supplementary Information figure
% Coastal protection vs. salt-marsh accretion: a short-blanket syndrome
% by Davide Tognin
% version: 20201222

clearvars
close all
clc

Nfig = 0;

%% ----- IMPORT DATA ------------------------------------------------------
% read water level data
opts1 = detectImportOptions('WaterLevel.csv');
opts1.VariableTypes(1) = {'datetime'};
M = readtimetable('WaterLevel.csv',opts1);

% read data single station
opts2 = detectImportOptions('SingleStation.csv');
opts2.VariableTypes(1:2) = {'categorical'};
opts2.VariableTypes(4:5) = {'datetime'};
S = readtable('SingleStation.csv',opts2);

% read data averaged over study sites
opts3 = detectImportOptions('SiteAveraged.csv');
opts3.VariableTypes(1) = {'categorical'};
opts3.VariableTypes(3:4) = {'datetime'};
T = readtable('SiteAveraged.csv',opts3);

% read accretion measurements
opts4 = detectImportOptions('Accretion.csv');
opts4.VariableTypes(1:2) = {'categorical'};
AC = readtable('Accretion.csv',opts4);

clear opts*

%% ----- FIGURE 1: SEDIMENTATION ------------------------------------------
A = unique(T.area);

tbeg0 = datetime('01-Oct-2018');
tend0 = datetime('30-Oct-2020');

Nfig = Nfig + 1;
figure(Nfig)
hold on

for a = 1:length(A)

    % select data
    cond = (T.area == A(a));
    T2 = T(cond,:);
    
    dstart = T2.Tstart;
    dend   = T2.Tend;
    Dday = days(6);
    dend2 = dend - Dday;
    dmed =  T2.Tstart + duration(T2.Tend - T2.Tstart)/2;
   
    % ----- SUBPLOT AREA A ------------------------------------------------
    sb = subplot(3,1,a);   
    hold on  
    
    % ----- TOTAL SEDIMENTATION 
    yyaxis('left')
    hold on
    
    bar(dend2,T2.sed);
    ylabel('Sed. Acc. (g m^{-2})'); 
   
    % ----- SEDIMENTATION RATE
    yyaxis('right')
    hold on
    
    plot(dmed,T2.sedR,'LineStyle','-','Marker','o');
    ylabel('Sed. Rate (g m^{-2} d^{-1})'); 
  
    title(char(A(a)));
    clear T2
end

%% ----- SUPPLEMENTARY FIGURE 1: ORGANIC MATTER ---------------------------

Nfig = Nfig + 1;
figure(Nfig)
hold on

for a = 1:length(A)

    % select data
    cond = (T.area == A(a));
    T2 = T(cond,:);
    
    dstart = T2.Tstart;
    dend   = T2.Tend;
    Dday = days(6);
    dend2 = dend - Dday;
    dmed =  T2.Tstart + duration(T2.Tend - T2.Tstart)/2;
  
    
    % ----- SUBPLOT ORGANIC MATTER ----------------------------------------
    sb = subplot(3,2,2*a -1);   
    hold on  
    
    % ----- ORGANIC MATTER
    yyaxis('left')
    hold on
    
    bar(dend2,T2.OMtot);
    ylabel('OM Acc. (g m^{-2})'); 
   
    % ----- ORGANIC MATTER RATE
    yyaxis('right')
    hold on
    
    plot(dmed,T2.OMrate,'LineStyle','-','Marker','o');  
    ylabel('OM Rate (g m^{-2} d^{-1})'); 
  
    title(char(A(a)));

    % ----- ORGANIC MATTER PERCENTAGE 
    sb = subplot(3,2,2*a);   
    
    bar(dend2,T2.OM100*100);
    ylabel('OM Rate (% weight)'); 
    title(char(A(a)));
    clear T2
end

%% ----- SUPPLEMENTARY FIGURE 2: ACCRETION --------------------------------
% group by period and area
G = findgroups(S.year,S.station);

% table to save yearly data
varN = {'station' 'year' 'accC'};
varT = {'categorical' 'categorical' 'double'};
Asum = table('Size',[max(G) length(varN)],...
            'VariableTypes',varT,...
            'VariableNames',varN);
clear varN varT
Asum.station = splitapply(@(x) unique(x),S.station,G);
Asum.year    = splitapply(@(x) unique(x),S.year,G);
% yearly accretion
Asum.accC = splitapply(@(x) sum(x),S.Accretion,G);

AA = join(AC,Asum,'Keys',{'station','year'});

Nfig = Nfig + 1;
figure(Nfig)
bis = 0:1:10;

hold on
scatter(AA.accretion,AA.accC)
plot(bis,bis,'k');

axis equal
xlim([0 10]);
ylim([0 10]);

xlabel('measured accretion (mm)');
ylabel('computed accretion (mm)')


%% ----- DIVIDE STORM AND FAIR WEATHER DATA -------------------------------
% group by period and area
G = findgroups(T.area,T.year);

% table to save yearly data
varN = {'area' 'year' ...
        'sedT' 'sedS' 'sedF' 'sedS100' 'sedF100' ...
        'dayT' 'dayS' 'dayF' 'dayS100' 'dayF100' ...
        'sedS_mod' 'sedF_mod' 'sedS_flood' 'sedF_flood' ...
        'accT' ...
        'accS_mod' 'accF_mod' 'accS_flood' 'accF_flood'};
varT = {'categorical' 'categorical' ...
        'double' 'double' 'double' 'double' 'double' ...
        'double' 'double' 'double' 'double' 'double' ...
        'double' 'double' 'double' 'double'...
        'double' ...
        'double' 'double' 'double' 'double'};
Tsum = table('Size',[2*length(A) length(varN)],...
            'VariableTypes',varT,...
            'VariableNames',varN);
TsumM = table('Size',[2 length(varN)],...
            'VariableTypes',varT,...
            'VariableNames',varN);
clear varN varT

Tsum.area    = splitapply(@(x) unique(x),T.area,G);
Tsum.year    = splitapply(@(x) unique(x),T.year,G);
% sedimentation measured (storm + fair weather)
Tsum.sedT    = splitapply(@(x) sum(x),T.sed,G);
Tsum.sedS    = splitapply(@(x) sum(x),T.sed(T.storm == 1),G(T.storm == 1));
Tsum.sedF    = splitapply(@(x) sum(x),T.sed(T.storm ~= 1),G(T.storm ~= 1));
Tsum.sedS100 = Tsum.sedS./Tsum.sedT;
Tsum.sedF100 = Tsum.sedF./Tsum.sedT;
% time (storm + fair weather)
Tsum.dayT    = splitapply(@(x) sum(x),T.duration,G);
Tsum.dayS    = splitapply(@(x) sum(x),T.duration(T.storm == 1),G(T.storm == 1));
Tsum.dayF    = splitapply(@(x) sum(x),T.duration(T.storm ~= 1),G(T.storm ~= 1));
Tsum.dayS100 = Tsum.dayS./Tsum.dayT;
Tsum.dayF100 = Tsum.dayF./Tsum.dayT;
% sedimentation modelled (storm + fair weather)
Tsum.sedS_mod    = splitapply(@(x) sum(x),T.sed_mod(T.storm == 1),G(T.storm == 1));
Tsum.sedF_mod    = splitapply(@(x) sum(x),T.sed_mod(T.storm ~= 1),G(T.storm ~= 1));
% sedimentation flood-regulated (storm + fair weather)
Tsum.sedS_flood  = splitapply(@(x) sum(x),T.sed_flood(T.storm == 1),G(T.storm == 1));
Tsum.sedF_flood  = splitapply(@(x) sum(x),T.sed_flood(T.storm ~= 1),G(T.storm ~= 1));
% time (storm + fair weather)
Tsum.accT        = splitapply(@(x) sum(x),T.Accretion,G);
% accretion modelled (storm + fair weather)
Tsum.accS_mod    = splitapply(@(x) sum(x),T.Accretion_mod(T.storm == 1),G(T.storm == 1));
Tsum.accF_mod    = splitapply(@(x) sum(x),T.Accretion_mod(T.storm ~= 1),G(T.storm ~= 1));
% accretion flood-regulated (storm + fair weather) 
Tsum.accS_flood  = splitapply(@(x) sum(x),T.Accretion_flood(T.storm == 1),G(T.storm == 1));
Tsum.accF_flood  = splitapply(@(x) sum(x),T.Accretion_flood(T.storm ~= 1),G(T.storm ~= 1));

% compute yearly average
GM = findgroups(Tsum.year);
TsumM.area = categorical({'mean'; 'mean'});
TsumM.year =  splitapply(@(x) unique(x),Tsum.year,GM);
for i = 3:width(TsumM)
TsumM.(i)    = splitapply(@(x) mean(x),Tsum.(i),GM);
end

Tsum = [Tsum; TsumM];
clear TsumM

%% ----- FIGURE 2: STORM CONTRIBUTION -------------------------------------
gLabel = cell(height(Tsum),1);
for i = 1:height(Tsum)
    gLabel(i) = strcat(cellstr(Tsum.area(i)),'-',sprintf('%d',Tsum.year(i)));
end

Tsed = Tsum{:,["sedS100" "sedF100"]};
Tday = Tsum{:,["dayS100" "dayF100"]};

NumGroupsPerAxis = size(Tsed, 1);
NumStacksPerGroup = size(Tsed, 3);

% Count off the number of bins
groupBins = 1:NumGroupsPerAxis;
MaxGroupWidth = 0.75; 
groupOffset = MaxGroupWidth/NumStacksPerGroup;

Nfig = Nfig + 1;
figure(Nfig);
hold on; 

% ----- SUBPLOT: time
subplot(1,2,2)
for i = 1:NumStacksPerGroup

    Y = Tday;
    
    % Center the bars:
    internalPosCount = i - ((NumStacksPerGroup+1) / 2);
    
    % Offset the group draw positions:
    groupDrawPos = (internalPosCount)* groupOffset + groupBins;
    
    barh(Y, 'stacked'); 
end

hold off;
set(gca,'Xlim',[0 1]);
set(gca,'XTick',[0 0.25 0.5 0.75 1]);
set(gca,'YTickMode','manual');
set(gca,'YTick',1:NumGroupsPerAxis);
set(gca,'YTickLabel',gLabel);
xlabel('% time');

% ----- SUBPLOT: sedimentation
subplot(1,2,1)
for i = 1:NumStacksPerGroup

    Y = Tsed;
    
    % Center the bars:
    internalPosCount = i - ((NumStacksPerGroup+1) / 2);
    
    % Offset the group draw positions:
    groupDrawPos = (internalPosCount)* groupOffset + groupBins;
    
    h(i,:) = barh(Y, 'stacked'); 
    set(h(i,:),'BarWidth',groupOffset - 0.05);
    set(h(i,:),'XData',groupDrawPos);
  
    h(i,1).DisplayName = 'storm events';
    h(i,2).DisplayName = 'fair weather';   
end

hold off;
set(gca,'Xlim',[0 1]);
set(gca,'XTick',[0 0.25 0.5 0.75 1]);
set(gca,'YTickMode','manual');
set(gca,'YTick',1:NumGroupsPerAxis);
set(gca,'YTickLabelMode','manual');
set(gca,'YTickLabel',[]);

xlabel('% sedimentation');
lgnd = legend('Location','SouthOutside','Orientation','horizontal');

lgnd.Position(1) = 0.5 - lgnd.Position(3)/2;
lgnd.Position(2) = 0.93;

%% ----- FIGURE 3: SEDIMENTATION RATE-TIDE RELATION -----------------------
% ---- global model
x = T{:,"MID"};
y = T{:,"sedR"};

modelfun = @(b,x) b(1)*exp(b(2)*x);
beta0 = [2 15];
beta = fitnlm(x,y,modelfun,beta0);
a = beta.Coefficients.Estimate('b1');
b = beta.Coefficients.Estimate('b2');
xm = min(x):0.001:max(x);
ym = a*exp(b*xm);

Nfig = Nfig + 1;
figure(Nfig)
hold on

condS = T.storm == true;
xS = x(condS);
yS = y(condS);
xF = x(~condS);
yF = y(~condS);
scatter(xS, yS, 'SizeData',25,'Marker','.','DisplayName','storm events');
scatter(xF, yF, 'SizeData',25,'Marker','.','DisplayName','fair weather');
plot(xm,ym,'Marker','none','Color','k','LineWidth',1,...
    'HandleVisibility','off');
xlabel('Mean Inundation Depth (m)');
ylabel('Sedimentation Rate (g m^{-2} d^{-1} )');

set(gca,'Yscale','log');
legend('Location','SouthWest')

% ---- only storm data
betaS = fitnlm(xS,yS,modelfun,beta0);
aS = betaS.Coefficients.Estimate('b1');
bS = betaS.Coefficients.Estimate('b2');
ymS = aS*exp(bS*xm);

Nfig = Nfig + 1;
figure(Nfig)
hold on

scatter(xS, yS, 'SizeData',25,'Marker','.','DisplayName','storm events');
plot(xm,ymS,'Marker','none','Color','k','LineWidth',1,...
    'HandleVisibility','off');
plot(xm,ym,'Marker','none','Color','k','LineStyle','--','LineWidth',1,...
    'HandleVisibility','off');
xlabel('Mean Inundation Depth (m)');
ylabel('Sedimentation Rate (g m^{-2} d^{-1} )');

set(gca,'Yscale','log');
legend('Location','SouthWest')

% ----- single study area
Nfig = Nfig + 1;
figure(Nfig)
hold on

for a = 1:length(A)

    % select data
    cond = (T.area == A(a));
    T2 = T(cond,:); 
    x = T{cond,"MID"};
    y = T{cond,"sedR"};

    betaA = fitnlm(x,y,modelfun,beta0);
    aA = betaA.Coefficients.Estimate('b1');
    bA = betaA.Coefficients.Estimate('b2');
    ym = aA*exp(bA*xm);
   
    % ----- SUBPLOT AREA A ------------------------------------------------
    sb = subplot(3,1,a);   
    hold on  
    
    condS = T2.storm == true;
    xS = x(condS);
    yS = y(condS);
    xF = x(~condS);
    yF = y(~condS);
    scatter(xS, yS, 'SizeData',25,'Marker','.');
    scatter(xF, yF, 'SizeData',25,'Marker','.');
    plot(xm,ym,'Marker','none','Color','k','LineWidth',1);
    xlabel('Mean Inundation Depth (m)');
    ylabel('Sedimentation Rate (g m^{-2} d^{-1} )');
    set(gca,'Yscale','log');
  
    title(char(A(a)));

end


%% ----- FIGURE 4: FLOOD REGULATED SCENARIO -------------------------------

Nfig = Nfig + 1;
figure(Nfig);
hold on; 

% ----- SUBPLOT: sediment accumulation
Tsed(:,:,1) = Tsum{:,[ "sedF_mod" "sedS_mod"]};
Tsed(:,:,2) = Tsum{:,[ "sedF_flood" "sedS_flood"]};

NumGroupsPerAxis = size(Tsed, 1);
NumStacksPerGroup = size(Tsed, 3);

% Count off the number of bins
groupBins = 1:NumGroupsPerAxis;
MaxGroupWidth = 0.75; 
groupOffset = MaxGroupWidth/NumStacksPerGroup;

subplot(1,2,1)
hold on
for i = 1:NumStacksPerGroup

    Y = squeeze(Tsed(:,:,i));
    
    % Center the bars:
    internalPosCount = i - ((NumStacksPerGroup+1) / 2);
    
    % Offset the group draw positions:
    groupDrawPos = (internalPosCount)* groupOffset + groupBins;
    
    h(i,:) = bar(Y, 'stacked'); 
    set(h(i,:),'BarWidth',groupOffset);
    set(h(i,:),'XData',groupDrawPos);
end

hold off;
set(gca,'XTickMode','manual');
set(gca,'XTick',1:NumGroupsPerAxis);
set(gca,'XTickLabelMode','manual');
set(gca,'XTickLabel',gLabel);
ylabel('Sediment accumulation (g m^{-2})');

% ----- SUBPLOT: accretion
Tacc(:,:,1) = Tsum{:,[ "accF_mod" "accS_mod"]};
Tacc(:,:,2) = Tsum{:,[ "accF_flood" "accS_flood"]};

NumGroupsPerAxis = size(Tacc, 1);
NumStacksPerGroup = size(Tacc, 3);

% Count off the number of bins
groupBins = 1:NumGroupsPerAxis;
MaxGroupWidth = 0.75; 
groupOffset = MaxGroupWidth/NumStacksPerGroup;

subplot(1,2,2)
hold on
for i = 1:NumStacksPerGroup

    Y = squeeze(Tacc(:,:,i));
    
    % Center the bars:
    internalPosCount = i - ((NumStacksPerGroup+1) / 2);
    
    % Offset the group draw positions:
    groupDrawPos = (internalPosCount)* groupOffset + groupBins;
    
    h(i,:) = bar(Y, 'stacked'); 
    set(h(i,:),'BarWidth',groupOffset);
    set(h(i,:),'XData',groupDrawPos);
end

hold off;
set(gca,'XTickMode','manual');
set(gca,'XTick',1:NumGroupsPerAxis);
set(gca,'XTickLabelMode','manual');
set(gca,'XTickLabel',gLabel);
ylabel('Accretion (mm)');

%% ----- SUPPLEMENTARY FIGURE 5: SEDIMENT ACCUMULATION SCENARIOS ----------

Nfig = Nfig + 1;
figure(Nfig);
hold on

for a = 1:length(A)
    % select data
    cond = (T.area == A(a));
    T2 = T(cond,:);
    
    dstart = T2.Tstart;
    dend   = T2.Tend;
    Dday = days(6);
    dend2 = dend - Dday;
    dmed =  T2.Tstart + duration(T2.Tend - T2.Tstart)/2;
    sedCr = T2{:,{'sed' 'sed_mod' 'sed_flood'}};
      
    subplot(3,1,a)
    hold on
       
    bp = bar(dend2,sedCr);
    bp(1,1).DisplayName = 'measured';
    bp(1,2).DisplayName = 'modelled - today';
    bp(1,3).DisplayName = 'regulated';
    
    xlim([datetime('01-Oct-2018') datetime('30-Oct-2020')])
    legend('Location','NorthWest','Orientation','horizontal')    
    ylabel('Sediment accumulation (g m^{-2})');
    
    box off
    title(char(A(a)));
    
end

%% ----- SUPPLEMENTARY FIGURE 6: SEDIMENT ACCRETION SCENARIOS -------------

Nfig = Nfig + 1;
figure(Nfig);
hold on

for a = 1:length(A)
    % select data
    cond = (T.area == A(a));
    T2 = T(cond,:);
    
    dstart = T2.Tstart;
    dend   = T2.Tend;
    Dday = days(6);
    dend2 = dend - Dday;
    dmed =  T2.Tstart + duration(T2.Tend - T2.Tstart)/2;
    sedCr = T2{:,{'Accretion' 'Accretion_mod' 'Accretion_flood'}};
      
    subplot(3,1,a)
    hold on
       
    bp = bar(dend2,sedCr);
    bp(1,1).DisplayName = 'measured';
    bp(1,2).DisplayName = 'modelled - today';
    bp(1,3).DisplayName = 'regulated';
    
    xlim([datetime('01-Oct-2018') datetime('30-Oct-2020')])
    legend('Location','NorthWest','Orientation','horizontal')    
    ylabel('Accretion (mm)');
    
    box off
    title(char(A(a)));
    
end






